@@ -1,10 +1,10 @@
 # -*- coding: utf8 -*-
 from .. import descriptors
-from .handler import Before, After
+from .handler import BeforeHandler, AfterHandler
 from .value import Value
 
 class Descriptor(descriptors.Named):
     ValueType = Value
-    before = Before()
-    after = After()
+    before = BeforeHandler()
+    after = AfterHandler()
 
